.g-oauth-provider-list-title{margin:10px 0;font-size:16px;color:#555;border-bottom:1px solid #eee}.g-oauth-value-container{margin:10px 0;padding:3px 9px;border:1px solid #ddd;background-color:#f6f6f6}.g-oauth-value-container .g-oauth-value{display:inline-block;margin-left:15px;font-family:monospace}.g-reg-policy-config-container{border-radius:3px;padding:15px 15px 5px;border:1px solid #e2e2e2;background-color:#f7f7f7;margin-bottom:30px}.g-oauth-container{margin-top:20px}.g-oauth-container .g-oauth-section-header{height:2px;background-color:#dcd6d6;margin-bottom:16px;font-size:12px;text-align:center}.g-oauth-container .g-oauth-section-header-text{display:inline;background-color:#fff;position:relative;top:-7px;padding:0 7px;color:#878080}.g-oauth-button{width:160px;border-radius:3px;padding:7px 11px;display:inline-block;cursor:pointer;margin-right:15px;margin-bottom:10px}.g-oauth-button .g-oauth-button-icon{display:inline-block;padding-right:6px;border-right:1px solid #fff}.g-oauth-button .g-oauth-button-text{display:inline-block;text-align:center;width:109px}.g-oauth-button-google{background-color:#dc4e41;border:1px solid #a82b1f;color:#fff}.g-oauth-button-google:hover{background-color:#cd3426}.g-oauth-button-google .g-oauth-button-icon{border-right-color:#a82b1f}.g-oauth-button-globus{background-color:#2b5693;border:1px solid #1e3c67;color:#fff}.g-oauth-button-globus:hover{background-color:#25497d}.g-oauth-button-globus .g-oauth-button-icon{border-right-color:#1e3c67}.g-oauth-button-github{background-color:#333;border:1px solid #242424;color:#fff}.g-oauth-button-github:hover{background-color:#2b2b2b}.g-oauth-button-github .g-oauth-button-icon{border-right-color:#242424}.g-oauth-button-linkedin{background-color:#0077b5;border:1px solid #00537f;color:#fff}.g-oauth-button-linkedin:hover{background-color:#00659a}.g-oauth-button-linkedin .g-oauth-button-icon{border-right-color:#00537f}.g-oauth-button-bitbucket{background-color:#205081;border:1px solid #16385a;color:#fff}.g-oauth-button-bitbucket:hover{background-color:#1b446e}.g-oauth-button-bitbucket .g-oauth-button-icon{border-right-color:#16385a}.g-oauth-button-microsoft{background-color:#00a1f1;border:1px solid #0071a9;color:#fff}.g-oauth-button-microsoft:hover{background-color:#0089cd}.g-oauth-button-microsoft .g-oauth-button-icon{border-right-color:#0071a9}.g-oauth-button-box{background-color:#0081c6;border:1px solid #005a8b;color:#fff}.g-oauth-button-box:hover{background-color:#006ea8}.g-oauth-button-box .g-oauth-button-icon{border-right-color:#005a8b}.g-oauth-button-cilogon{background-color:#696;border:1px solid #476b47;color:#fff}.g-oauth-button-cilogon:hover{background-color:#578257}.g-oauth-button-cilogon .g-oauth-button-icon{border-right-color:#476b47}
